pub fn rust_panic_backtrace() -> RustBacktraceExpand description
The effective panic backtrace setting for the current thread: the
thread-local override if present, else RUST_BACKTRACE (only).
pub fn rust_panic_backtrace() -> RustBacktraceThe effective panic backtrace setting for the current thread: the
thread-local override if present, else RUST_BACKTRACE (only).